// *********************  FILE:  olist.cc  *******************************
//
// This file contains the definitions for the class OrderedList.
//
// Programmer:  J. Ingram
// Date:  January 22, 1997
// Updated:  May 27, 1997 (to use the class simNode for the
//                         nodes in the list)
//
// Usage:   User-defined auxiliary files needed:
//
//                olist.h,  the declaration file for the class
//                          OrderedList
//                snode.h,  the declaration file for the class
//                          sNode
// **********************************************************************
#include "olist.h"

using namespace std;

#include <iostream>

// *****************************************
// *******  OrderedList Definitions  *******
// *****************************************

// ==============================================
// Construct an empty list
//
// PRE:  The OrderedList object is undefined
//
// POST: The list is empty (the pointer to the
// first node is NULL)
// ==============================================
OrderedList::OrderedList()
{
   First = NULL;
 }


// ===============================================================
// insert inserts a simNode in the ordered list in the
// appropriate place based on the time field of the node
//
// PRE:  The list is defined with the nodes in ascending order
//       by the time field; the argument is a pointer to the
//       simNode to be added to the list
//      
// POST: The list contains the node pointed to by the argument; 
// nodes in the list are in ascending order by the time field.
// ===============================================================
void OrderedList::insert(simNode * newnode)
{
   simNode *lead,       // lead pointer for traversing the list
           *trail;      // trail pointer -- always one node behind lead
   int found;           // flag to indicate when the appropriate spot 
                        // in the list has been found

   // traverse the list to find the appropriate spot for the new node
   found = 0;
   lead = First;
   trail = NULL;
   while ( (lead != NULL) && (!found) )
   {
       if (lead->time < newnode->time)
       { 
            trail = lead;
            lead = lead->next;
       }
       else
       {
            found = 1;
       }  
   } 

   // insert the new node between the nodes pointed to by the lead 
   // and trail pointers 
   newnode->next = lead;
   if (trail != NULL)
       trail->next = newnode;
   else
       First = newnode;

} 

   
// =====================================================================
// getFirst removes the first node from the list and returns a pointer
// to that node.  The node removed is the one with the earliest time
// (smallest value of the time field)
//
// PRE:   The list is defined with the nodes in increasing order by
//        the time field.
//
// POST:  A pointer to the node with the earliest time field is returned;
// the list, without that node, remains in increasing order by time.
// ======================================================================
simNode * OrderedList::getFirst ()
{
    simNode * smallest;
    smallest = First;
    if (smallest != NULL)
       First = First->next;
    return (smallest);
}
 

// ===========================================
// display prints out each node on the list
// ===========================================
void OrderedList::display()
{
   simNode *ptr;    // pointer for traversing the list

   // traverse the list displaying each node
   ptr = First;
   while (ptr != NULL)  {
      ptr->display();
      ptr = ptr->next;
    }
   cout << endl;
 }









