// ***********************  FILE:  queue.h  *************************
//
// This file contains the declaration of the class Queue
//
// A Queue is a linked list of simNodes maintained as a FIFO list.
//
// Programmer:  J. Ingram
// Date:  January 22, 1997
// Updated:  May 27, 1997 (to use simNodes as the list nodes)
//
// Class Queue is a FIFO list of nodes of class simNode.  A queue object 
// keeps the following statistics about itself:
//             -- the number in the queue
//             -- the total time spent in the queue (by all nodes) --
//                (this is the total area under the number in queue curve)
//             -- the last time the queue was modified
//
// The data member front always points to the first element in the queue
// (the node that has been in the queue the longest amount of time) and
// the data member rear always points to the most recent element placed
// on the queue.
// ******************************************************************
#ifndef QUEUE_DEF
#define QUEUE_DEF

#include "snode.h"

// ************************************
// *******  Queue Declarations  *******
// ************************************
class Queue
{
 public: 
    Queue();                        // constructs an empty queue

    void enqueue (simNode *, double); // adds a node to the rear of the queue
                                    // the first argument is a pointer to
                                    // the node to be added; the second
                                    // argument is the time the node is
                                    // added (used for statistical purposes)

    simNode * dequeue (double);     // removes the front node from the
                                    // queue and returns a pointer to it;
                                    // the argument is the time the node
                                    // is removed (used for statistical
                                    // purposes)

    int empty ();                   // returns TRUE (1) if the queue is 
                                    // empty; otherwise returns FALSE (0)

    double totalArea ();            // returns the total area under the
                                    // number in queue curve 

    void display ();                // displays the data members of the
                                    // queue and the nodes in the queue

  private:
    int niq;                        // number of nodes in the queue

    double area;                    // area under the number in the queue
                                    // curve

    double lasttime;                // the last time the number in the
                                    // queue changed (used in calculation
                                    // of the area)

    simNode * front;                // pointer to the front node in the queue

    simNode * rear;                 // pointer to the rear node in the queue
  };
#endif






