// ******************  FILE:  rand.h  **************************
//
// Declaration file for the class RandNum
//
// Programmer:  J. Ingram
// Date:  January 22, 1997
//
// Objects of type RandNum can be random numbers generated 
// from an exponential distribution (with a given mean), or
// from a uniform distribution (with given lower and upper 
// bounds), or they can be uniformly distributed between 0
// and 1 (the default).
//
// 100 different streams are provided in the class (each
// stream has a different seed for starting the random number
// generation
//
// *************************************************************
#ifndef RAND_DEF
#define RAND_DEF

class RandNum  
{
  public:
    RandNum ();                  // default constructor

    RandNum (int strm);          // constructor for a random number
                                 // uniformly distributed between 0
                                 // and 1.  The argument is a stream
                                 // number (between 1 and 100, inclusive).

    RandNum (int strm, double mean); // constructor for a random number
                                     // exponentially distributed with
                                     // a given mean (second argument).
                                     // The first argument is a stream 
                                     // number (1 - 100).

    RandNum (int strm, double min, double max);
                                     // Constructor for a random number
                                     // uniformly distributed between min
                                     // and max.  The first argument is a
                                     // stream number (1 - 100).

    int getStream ();                // returns the stream number

    double nextNum ();               // nextNum generates and returns the
                                     // next number in the random number
                                     // stream.

    double mean();                   // returns the mean of the distribution
                                    
    double upperbd();                // returns the maximum number in the
                                     // distribution (for uniformly 
                                     // distributed numbers)

    double lowerbd();                // returns the minimum number in the
                                     // distribution (for uniformly 
                                     // distributed numbers)

    void setStream (int strm);       // sets the stream number to the value
                                     // given in the argument if that value
                                     // is valid; otherwise it sets the stream
                                     // number to 1

    void display();                  // displays the data members of the
                                     // random number

  private:
    static int seedtable[];          // table of 100 seeds -- shared by
                                     // all objects of type RandNum

    int stream;                      // stream number (index into the seed
                                     // table) for random number generation
   
    char dist;                       // distribution (r, e or u -- for
                                     // random number (uniformly distributed
                                     // between 0 and 1), exponentially
                                     // distributed, or uniformly distributed

    double mn;                       // mean of the distribution

    double ub;                       // upper bound of uniform distribution

    double lb;                       // lower bound of uniform distribution

    double rand();                   // generates a number uniformly 
                                     // distributed between 0 and 1
  };

#endif





