// *********************  FILE:  snode.cc  *******************************
//
// This file contains the definitions for the class simNode
//
// Programmer:  J. Ingram
// Date:  May 27, 1997
//
// Usage:   User-defined auxiliary files needed:
//
//                snode.h,  the declaration file for the class simNode
//
// **********************************************************************
#include "snode.h"

using namespace std;
#include <iostream>

// *************************************
// *******  simNode Definitions  *******
// *************************************

// ====================================================================
// Default constructor for a simNode
//
// PRE:  The simNode object is undefined
//
// POST: The time and type fields are set to 0; the next field to NULL
// ====================================================================
simNode::simNode () 
{   
  time = 0.0;
  type = 0;
  next = NULL;  
}


// ==========================================================
// Construct a simNode with a given time field.
//
// PRE:  The simNode object is undefined; the argument (double)
// is the time the event is to occur (for nodes on the event list).
//       
// POST: The time field is set to the value of the argument; 
// the type field is set to 0; the next field is NULL
// ==========================================================
simNode::simNode (double whenHappens)
{ 
  time = whenHappens;
  type = 0;
  next = NULL; 
}

// ================================================================
// Construct a simNode with a given time field and a given type.
//
// PRE:  The simNode object is undefined; the first argument
// (double) gives the time for an event to occur, the second
// argument gives the type of event when the node represents an
// event on the event list
//
// POST:  The time and type fields are set to the given arguments;
// the next field is NULL
// ================================================================
simNode::simNode (double when, int what)
{ 
  time = when;
  type = what;
  next = NULL; 
}


// ====================================
// Return the value of the time field
// ====================================
double simNode::getTime ()
     { return time; }


// ====================================
// Return the value of the type field
// ====================================
int simNode::getType ()
     { return type; }

// ============================================================
// Set the time field of the simNode to the time given in the 
// argument
//
// PRE:  The argument gives the value for the time field of the
// simNode object.
//
// POST: The time field of the simNode object is set to the value
// of the argument.
// ============================================================
void simNode::setTime (double when)
     { time = when; }

// =============================================================
// Set the type field to the type given in the argument
//
// PRE:  The argument gives the event type (an integer)
//
// POST: The type field of the simNode is set to the value of the
// argument
// ==============================================================
void simNode::setType (int etype)
     { type = etype; }

// ===========================================
// Display the time and type of the simNode
// ===========================================
void simNode::display()
     { cout << time << "\t" << type << endl; }








