// ********************  FILE:  snode.h  *************************
// 
// This file contains the declarations for the class simNode 
//
// Programmer:  J. Ingram
// Date:  May 27, 1997
//
// Class simNode is a class of nodes to go on lists (such as the event 
// list and queues) in a simulation.  A simNode has at least three fields:  
// a time field (which contains the time the event is scheduled to occur
// when the node represents an event on the event list) (double), a type 
// field (to indicate the type of event) (int), and a pointer to the next 
// node in the list.
//  
// *************************************************************** 
#ifndef SIMNODE_DEF
#define SIMNODE_DEF

// ********************************************
// *******      simNode Declaration     *******
// ********************************************

class simNode
{
 friend class OrderedList;
 friend class Queue;              // Private members of class simNode may
                                  // be modified by objects of type
                                  // OrderedList and Queue 
 public:
   simNode ();                    // Constructs an empty simNode

   simNode (double);              // Constructs a simNode with a specified
                                  // time field (the double argument)

   simNode (double, int);         // Constructs an simNode with a specified
                                  // time field (the double argument) and
                                  // a specified type (the int argument)

   double getTime ();             // returns the value of the time field
   int getType ();                // returns the value of the type field
   void setTime (double);         // sets the time field
   void setType (int);            // sets the type field
   void display ();               // displays the data members of the simNode

 private:
   double time;                   // the time of occurrence of the event when
                                  // the node represents an event
   int type;                      // the type of the event
   simNode * next;                // pointer to the next simNode on the list
                          
 };

#endif







