// ************************  FILE:  system.h  ***************************
//
// This file contains the declarations for the base class System.
//
// Programmer:  J. Ingram
// Date:  January 22, 1997
// Updated:  May 27, 1997 to use the class simNode for list nodes
// Updated: September 4, 2000 -- added scheduleDeparture function 
// Updated: January 13, 2003 to include an initialization option where
// system parameters are sent to initialize as arguments and to
// overload printReport.
//
// The System class is a generic class for a system that is to be
// simulated.  It contains data members and function members that
// are common to all systems and simulations of systems using the
// event scheduling method of simulation.
//
// *********************************************************************** 
#ifndef SYSTEM_DEF
#define SYSTEM_DEF
#include "olist.h"

// ***********************************
// ******  System Declarations  ******
// ***********************************
class System
{
 public:
    System();                           // Default constructor - sets system
                                        // time (the simulation clock) to 0
    void initialize();                  // Initialization routine
    double getTime();                   // Returns the current simulation time
    void simulate();                    // Simulates the system
    void scheduleEvent(simNode *);      // Schedules an event by placing it
                                        // on the eventList
    virtual void updateState(simNode *) = 0; // Updates the state of the
                                            // system based on the event
                                            // that just occurred (a pointer
                                            // to the event is the argument)
                                            // This virtual member function
                                            // is defined in classes derived
                                            // from the base class System
                                            // (that is, its definition depends
                                            // on the particular events in
                                            // the specific system)
    virtual int continueSim() = 0;       // A Boolean-valued function that
                                         // determines whether or not the
                                         // simulation of the system is to
                                         // continue.  The definition of
                                         // this function is given in
                                         // classes derived from the class
                                         // system.  It depends on the
                                         // specific system being simulated
                                         // AND the stopping condition used.
    void printReport();                  // Prints a report of the
                                         // simulation.
  protected:
    double systemTime;                   // Current simulated time (the
                                         // simulation clock)
    OrderedList eventList;               // The time-ordered list of
                                         // future events
  };

    
#endif
